@@ -130,7 +130,7 @@ def roundp(*args,**kwargs):
     a = [item for item in args]
     kw = {item:v for item,v in kwargs.items() if item in ['sigfigs', 'decimals']}
         
-    num_str = str(a[0])
+    num_str = str(float(a[0]))
         
     # Add trailing zeroes if needed
     
@@ -138,9 +138,10 @@ def roundp(*args,**kwargs):
         z = kw['sigfigs']
     elif kw.get('decimals', None):
         z = kw['decimals']
+    else:
+        z = 3 # Default sig figs
                         
-    if len(num_str) < z:
-        num_str = num_str + str(0)*z*2
+    num_str = num_str + str(0)*z*2
                 
     result = sigfig.round(num_str,**kwargs)
         
@@ -149,8 +150,10 @@ def roundp(*args,**kwargs):
         return float(result) # Note, sig figs will not be carried through if this is a float
     elif isinstance(a[0],str):
         return result
+    elif isinstance(a[0],int):
+        return int(float(result))
     else:
-        raise NotImplementedError
+        return sigfig.round(*args,**kwargs)
 
 def round_str(*args,**kwargs):
     
